<?php
// $Horde: horde/lib/Auth/imap.php,v 1.2 2001/04/17 03:12:54 jon Exp $

Horde::functionCheck('imap_open', true,
    'Auth_imap: Required IMAP functions were not found.');

/**
 * The Auth_imap class provides an IMAP implementation of the Horde
 * authentication system.
 *
 * Parameters:
 *  'server'        The hostname or IP address of the server.
 *  'protocol'      The connection protocol (e.g. 'imap', 'pop3', 'nntp').
 *  'port'          The server port to which we will connect.
 *  'folder'        The initial folder / mailbox to open.
 * 
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @author  Gaudenz Steinlin <gaudenz.steinlin@id.unibe.ch>
 * @version $Revision: 1.2 $
 * @since   Horde 1.3
 * @package horde.auth
 */
class Auth_imap extends Auth {

    /**
     * Hash containing connection parameters.
     * @var array $params
     */
    var $params = array();

    /**
     * Constructs a new IMAP authentication object.
     *
     * @param array $params   A hash containing connection parameters.
     */
    function Auth_imap($params = array())
    {
        $this->setParams($params);
    }

    /**
     * Take a hash and build the connection string out of it.
     * 
     * @param array $params   A hash specifying an IMAP mailbox.
     */
    function setParams($params)
    {
        if (empty($params['dsn'])) {
            if (isset($params['server'])) {
                $params['dsn'] = '{' . $params['server'];
            } else {
                $params['dsn'] = '{localhost';
            }
            
            if (isset($params['protocol'])) {
                $params['dsn'] .= '/' . $params['protocol'];
            } else {
                $params['dsn'] .= '/imap';
            }
            
            if (isset($params['port'])) {
                $params['dsn'] .= ':' . $params['port'] . '}';
            } else {
                $params['dsn'] .= ':143}';
            }
            
            if (isset($params['folder'])) {
                $params['dsn'] .= $params['folder'];
            }
        }
        $this->params = $params;
    }

    /**
     * Find out if a set of login credentials are valid.
     * 
     * @param string $userID       The userID to check.
     * @param array  $credentials  An array of login credentials. For IMAP,
     *                             this must contain a password entry.
     * 
     * @return boolean Whether or not the credentials are valid.
     */
    function authenticate($userID, $credentials)
    {
        if (Auth::checkAuth($userID)) {
            return true;
        }

        $imap = @imap_open($this->params['dsn'], $userID,
                           $credentials['password'], OP_HALFOPEN);

        if ($imap) {
            @imap_close($imap);
            Auth::setAuth($userID);
            return true;
        }

        @imap_close($imap);

        return false;
    }

    /**
     * Add a set of authentication credentials. Not implemented for IMAP.
     * 
     * @param string $userID       The userID to add.
     * @param array  $credentials  The credentials to be set.
     *
     * @return int This function will always return AUTH_ERROR_UNSUPPORTED.
     */
    function add($userID, $credentials)
    {
        return AUTH_ERROR_UNSUPPORTED;
    }

    /**
     * Update a set of authentication credentials. Not implemented for IMAP.
     * 
     * @param string $oldID        The old userID.
     * @param string $newID        The new userID.
     * @param array  $credentials  The new credentials
     *
     * @return int This function will always return AUTH_ERROR_UNSUPPORTED.
     */
    function update($oldID, $newID, $credentials)
    {
        return AUTH_ERROR_UNSUPPORTED;
    }

    /**
     * Delete a set of authentication credentials. Not implemented for IMAP.
     * 
     * @param string $userID The userID to delete.
     *
     * @return int This function will always return AUTH_ERROR_UNSUPPORTED.
     */
    function delete($userID)
    {
        return AUTH_ERROR_UNSUPPORTED;
    }

}
?>
