<?php
// $Horde: horde/lib/Auth/mcal.php,v 1.1 2001/02/22 16:26:58 chuck Exp $

Horde::functionCheck('mcal_open', true,
    'Auth_mcal: Required MCAL functions were not found.');

/**
 * The Auth_mcal class provides an MCAL implementation of the Horde
 * authentication system.
 *
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @version $Revision: 1.1 $
 * @since   Horde 1.3
 * @package horde.auth
 */
class Auth_mcal extends Auth {
    
    /**
     * Hash containing connection parameters.
     * @var array $params
     */
    var $params = array();
    
    
    /**
     * Constructs a new MCAL authentication object.
     *
     * @param array $params   A hash containing connection parameters.
     */
    function Auth_mcal($params = array())
    {
        $this->params = $params;
    }
	
    
    /**
     * Find out if a set of login credentials are valid.
     * 
     * @param string $userID       The userID to check.
     * @param array  $credentials  An array of login credentials. For MCAL, this must contain a password entry.
     * 
     * @return boolean Whether or not the credentials are valid.
     */
    function authenticate($userID, $credentials)
    {
        if (Auth::checkAuth($userID)) {
            return true;
        }
        
        $mcal = @mcal_open($this->params['calendar'], $userID, $credentials['password']);
        
        if ($mcal) {
            @mcal_close($mcal);
            Auth::setAuth($userID);
            return true;
        }
        
        @mcal_close($mcal);
        return false;
    }
    
    /**
     * Add a set of authentication credentials. Not implemented for MCAL.
     * 
     * @param string $userID       The userID to add.
     * @param array  $credentials  The credentials to be set.
     */
    function add($userID, $credentials)
    {
        return AUTH_ERROR_UNSUPPORTED;
    }
	
    /**
     * Update a set of authentication credentials. Not implemented for MCAL.
     * 
     * @param string $oldID        The old userID.
     * @param string $newID        The new userID.
     * @param array  $credentials  The new credentials
     */
    function update($oldID, $newID, $credentials)
    {
        return AUTH_ERROR_UNSUPPORTED;
    }

    /**
     * Delete a set of authentication credentials. Not implemented for MCAL.
     * 
     * @param string $userID The userID to delete.
     */
    function delete($userID)
    {
        return AUTH_ERROR_UNSUPPORTED;
    }

}
?>
