<?php
// $Horde: horde/lib/Auth/sql.php,v 1.6 2001/03/20 18:16:00 chuck Exp $

/**
 * The Auth_sql class provides a sql implementation of the Horde
 * authentication system.
 *
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @version $Revision: 1.6 $
 * @since   Horde 1.3
 * @package horde.auth
 */
class Auth_sql extends Auth {
    
    /**
     * Hash containing connection parameters.
     * @var array $params
     */
    var $params = array();
    
    /**
     * Handle for the current database connection.
     * @var resource $db
     */
    var $db;
    
    /**
     * Boolean indicating whether or not we're connected to the SQL server.
     * @var boolean $connected
     */
    var $connected = false;


    /**
     * Constructs a new SQL authentication object.
     *
     * @param array $params   A hash containing connection parameters.
     */
    function Auth_sql($params = array())
    {
        $this->params = $params;
    }
    
    
    /**
     * Attempts to open a persistent connection to the SQL server.
     *
     * @return constant AUTH_OK on success, AUTH_ERROR_* on failure.
     */
    function connect()
    {
        if (!$this->connected) {
            if (!is_array($this->params)) return AUTH_ERROR_PARAMS;
            if (!isset($this->params['phptype'])) return AUTH_ERROR_PARAMS;
            if (!isset($this->params['hostspec'])) return AUTH_ERROR_PARAMS;
            if (!isset($this->params['username'])) return AUTH_ERROR_PARAMS;
            if (!isset($this->params['password'])) return AUTH_ERROR_PARAMS;
            if (!isset($this->params['database'])) return AUTH_ERROR_PARAMS;
            if (!isset($this->params['table'])) return AUTH_ERROR_PARAMS;

            /* Connect to the SQL server using the supplied parameters. */
            include_once 'DB.php';
            $this->db = &DB::connect($this->params, true);
            if (DB::isError($this->db) || DB::isWarning($this->db)) {
                return AUTH_ERROR_CONNECT;
            }

            $this->connected = true;
        }

        return AUTH_OK;
    }
    
    /**
     * Disconnect from the SQL server and clean up the connection.
     *
     * @return boolean true on success, false on failure.
     */
    function disconnect()
    {
        if ($this->connected) {
            $this->connected = false;
            return $this->db->disconnect();
        }

        return true;
    }
    
    /**
     * Find out if a set of login credentials are valid.
     * 
     * @param string $userID       The userID to check.
     * @param array  $credentials  The credentials to use.
     * 
     * @return boolean Whether or not the credentials are valid.
     */
    function authenticate($userID, $credentials)
    {
        if (Auth::checkAuth($userID)) {
            return true;
        }
        
        if ($this->connect() != AUTH_OK) {
            // PEAR error
            return false;
        }
        
        /* Build the SQL query. */
        $query = 'SELECT user_id FROM ' . $this->params['table'];
        $query .= " WHERE user_id = '" . $this->db->quoteString($userID) . "'";
        $query .= " AND user_pass = '" . md5($credentials['password']) . "'";
        
        /* Execute the query. */
        $result = $this->db->query($query);
    
        if (!DB::isError($result)) {
            $row = $result->fetchRow(DB_GETMODE_ASSOC);
            if (is_array($row)) {
                $result->free();
                Auth::setAuth($userID);
                return true;
            } else {
                $result->free();
                return false;
            }
        } else {
            return false;
        }
    }
    
    /**
     * Add a set of authentication credentials.
     * 
     * @param string $userID       The userID to add.
     * @param array  $credentials  The credentials to add.
     */
    function add($userID, $credentials)
    {
        if ($this->connect() != AUTH_OK) return false;
        
        /* Build the SQL query. */
        $query = "INSERT INTO " . $this->params['table'] . " (user_id, user_pass) ";
        $query .= "VALUES ('" . $this->db->quoteString($userID) . "', '" . md5($credentials['password']) . "')";
        
        /* Execute the query. */
        $result = $this->db->query($query);
        
        if ($result !== DB_OK) {
            return AUTH_ERROR;
        }

        return AUTH_OK;
    }
    
    /**
     * Update a set of authentication credentials.
     * 
     * @param string $oldID        The old userID.
     * @param string $newID        The new userID.
     * @param array  $credentials  The new credentials
     */
    function update($oldID, $newID, $credentials)
    {
        if ($this->connect() != AUTH_OK) return false;
        
        /* Build the SQL query. */
        $query = "UPDATE " . $this->params['table'] . " SET user_id = '" . $this->db->quoteString($newID) . "', user_pass = '" . md5($credentials['password']) . "'";
        $query .= "WHERE user_id = '" . $this->db->quoteString($oldID) . "'";
        
        /* Execute the query. */
        $result = $this->db->query($query);
        
        if ($result !== DB_OK) {
            return AUTH_ERROR;
        }
        return AUTH_OK;
    }
    
    /**
     * Delete a set of authentication credentials.
     * 
     * @param string $userID The userID to delete.
     */
    function delete($userID)
    {
        if ($this->connect() != AUTH_OK) return false;
        
        /* Build the SQL query. */
        $query = "DELETE FROM " . $this->params['table'];
        $query .= "WHERE user_id = '" . $this->db->quoteString($userID) . "'";
        
        /* Execute the query. */
        $result = $this->db->query($query);
        
        if ($result !== DB_OK) {
            return AUTH_ERROR;
        }
        return AUTH_OK;
    }
    
}
?>
