<?php

/**
 * The Menu:: class provides standardized methods for creating menus in
 * Horde applications.
 * 
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @author  Jon Parise <jon@horde.org>
 * @version $Revision: 1.4 $
 * @since   Horde 1.3
 * @package horde
 */
class Menu {
    
    /**
     * Generates the HTML for an item on the menu bar.
     *
     * @param $url       String containing the value for the hyperlink.
     * @param $text      String containing the label for this menu item.
     * @param $icon      (optional) String containing the filename of the image
     *                   icon to display for this menu item.
     * @param $icon_path (optional) If the icon lives in a non-default
     *                   directory, where is it?
     * @param $target    (optional) If the link needs to open in another frame
     *                   or window, what is its name?
     *
     * @return  string  String containing the HTML to display this menu item.
     */
    function createItem($url, $text, $icon = '', $icon_path = null, $target = false)
    {
        global $conf;
        
        $html = '<td align="center" valign="bottom" nowrap="nowrap">';
        $html .= '<a class="menuitem" href="' . $url . '" ';
        if ($target) {
            $html .= ' target="' . $target . '" ';
        }
        $html .= "onmouseover=\"status='$text'; return true;\" ";
        $html .= 'onmouseout="status=\'\';">';
        
        if (!empty($icon) && $conf['layout']['menu_images']) {
            $html .= Horde::img($icon, "alt=\"$text\"", $icon_path) . '<br />';
        }
        
        $html .= $text . "</a>&nbsp;</td>\n";
        
        return $html;
    }
    
    /**
     * Prints the result of the createItem() function.
     *
     * @param $url       String containing the value for the hyperlink.
     * @param $text      String containing the label for this menu item.
     * @param $icon      (optional) String containing the filename of the image
     *                   icon to display for this menu item.
     * @param $icon_path (optional) If the icon lives in a non-default
     *                   directory, where is it?
     * @param $target    (optional) If the link needs to open in another frame
     *                   or window, what is its name?
     */
    function printItem($url, $text, $icon = '', $icon_path = null, $target = false)
    {
        echo Menu::createItem($url, $text, $icon, $icon_path, $target);
    }
    
    /**
     * Creates a menu string from a custom menu item.  Custom menu items
     * can either define a new menu item or a menu separate (spacer).
     *
     * A custom menu item consists of a hash with the following properties:
     *
     *  'url'       The URL value for the menu item.
     *  'text'      The text to accompany the menu item.
     *  'icon'      The filename of an icon to use for the menu item.
     *  'icon_path' The path to the icon if it doesn't exist in the graphics/
     *              directory.
     *  'target'    The "target" of the link (e.g. '_top', '_blank').
     *
     * A menu separator item is simply a string set to 'separator'.
     *
     * @param $item     Mixed parameter containing the custom menu item.
     *
     * @return string   The resulting HTML to display the menu item.
     */
    function customItem($item)
    {
        global $conf;

        $text = '';

        if (is_array($item)) {
            $text = Menu::createItem($item['url'], $item['text'],
                        $item['icon'], $item['icon_path'], $item['target']);
        } else {
            if (strcasecmp($item, 'separator') == 0) {
                $text = '<td>&nbsp;</td>';
            }
        }

        return $text;
    }

}
?>
